clear;clc;
tic
%__________________________________________________________________________
% SOFTWARE: 
% Ran in MATLAB R2018a on a ThinkPad Carbon X1
%__________________________________________________________________________
% COMPUTER: 
% Processor	Intel(R) Core(TM) i7-8650U CPU @ 1.90GHz, 2112 Mhz, 4 Core(s), 8 Logical Processor(s)
% Installed Physical Memory (RAM)	16.0 GB
% System SKU	LENOVO_MT_20KH_BU_Think_FM_ThinkPad X1 Carbon 6th
% Run time: Elapsed time is 422.858128 seconds.
%__________________________________________________________________________
% FILE:
% Running this file produces all MATLAB based figures and tables in Labor
% Market Power (AER, 2022) - Berger, Herkenhoff, Mongey
% INPUTS: Contained in directories:
    % - Input_data_diles
        % - Clean_time_series_data.xls - HHI time series
    % - Input_parameter_vectors 
        % - Estimtated parameters under which model is solved
        % - xmin_A_nontradeable.mat  = Non-tradeable economy parameters - Table 3.I
        % - xmin_B_whole_economy.mat = All industry economy parameters  - Table 3.II
% OUTPUTS: User can start off with the following directories *empty* which will
% then be populated by mat-files, eps-files and tex-files:
    % - Created_mat_files
    % - Created_figure_files
    % - Created_table_files
% These are then loaded into the tex document for manuscript and appendix: 
    % - ../1_Draft/BHM_AER_manuscript.tex
    % - ../1_Draft/BHM_AER_online_appendix.tex
%__________________________________________________________________________
% NOTATION:
% Below, an * is used to denote output that appears in an Online Appendix 
% figure or table

%% A. RUN FILES
%__________________________________________________________________________
% CALIBRATE DISTRIBUTION OF NUMBER OF FIRMS ACROSS MARKETS
Figure_F1A_Table_F1_Fit_Mj_Distribution_Tradeable_Ind;
    % (Table*) - Distribution of firms across markets, M j ~ G ( M j ) , tradeable industries
    % (Figure*) - Distribution of the number of firms across sectors, tradeable industries
Figure_F1B_Table_F2_Fit_Mj_Distribution_All_Ind;       
    % (Table*) - Distribution of firms across markets, M j ~ G ( M j ) , all industries
    % (Figure*) - Distribution of the number of firms across sectors, all industries
    % Outputs: Nfit, Nfit_all, used in Compute_* code
%__________________________________________________________________________
% MAIN CODE
Compute_baseline_tax;                   % Uses xmin_A_nontradeable.mat
    % Outputs: baseline_tax
Compute_baseline_no_tax;                % Uses xmin_B_whole_economy.mat 
    % Outputs: baseline_no_tax
Compute_welfare_results;                             % -> (File) Outputs_welfare.mat
    % Outputs: base_mu_omega, Outputs_welfare
    
%% B. PRODUCE FIGURES AND TABLES
%__________________________________________________________________________
% SECTION 1 - INTRODUCTION
% Figure 1 - Schematic figure, drawn in Powerpoint.
    % See: ../1_Draft/Figures_drawn_in_Powerpoint/PowerPointFigures_BHM.pptx
%__________________________________________________________________________
% SECTION 2 - MODEL
% Figure 2 - Schematic figure, drawn in Powerpoint 
    % See: ../1_Draft/Figures_drawn_in_Powerpoint/PowerPointFigures_BHM.pptx
Figure_3_Example_Three_Markets;                      % -> (Figure 3) Oligopsonistic market equilibrium in three labor markets
%__________________________________________________________________________
% SECTION 3 - CALIBRATION
Table_3_Summary_of_Parameters;                       % -> (Table 3)  Summary of Parameters
Figure_4C_Labor_Supply_Elasticity_vs_Share;          % -> (Figure 4C) Reduced form and structural labor supply elasticties
Figure_5_Elasticities_in_Response_to_Shocks;         % -> (Figure 5) Reduced form and structural elasticities in response to idiosyncratic productivity shocks
%__________________________________________________________________________
% SECTION 4 - VALIDATION
Figure_6_Table_A1_Passthrough_Replication_of_KPWZ;   % -> (Figure 6, Table A1) Pass-through and replication of KPWZ   
Table_4_Strategic_Interaction_Replication_of_SSP;    % -> (Table 4) Strategic interaction and replication of Staiger, Spetz, and Phibbs (2010)
%__________________________________________________________________________
% SECTION 5 - WELFARE
Figure_7_Distribution_of_Labor_Market_Power;         % -> (Figure 7) Distribution of labor market power across firms
Table_5_Benchmark_Welfare_Gains_GHH;                 % -> (Table 5) Welfare gains from competition with GHH preferences
Figure_8I_Employment_Reallocation;                   % -> (Figure 8I) Employment reallocation from the benchmark economy to the efficient economy
Figure_8II_Example_Oligopsony_Competitive;           % -> (Figure 8II) Employment reallocation from the benchmark economy to the efficient economy
Figure_9_Welfare_Costs_with_Wealth_Effects;          % -> (Figure 9) Welfare costs of labor market power with wealth effects
%__________________________________________________________________________
% SECTION 6 - APPLICATION
Figure_10_11_Time_Series_Concentration_Labor_Share;  % -> (Figure 10) Measures of labor market concentration, 1977 to 2013
                                                     % -> (Figure 11) Change in labor share, 1977 to 2013
%__________________________________________________________________________
% OTHER APPENDIX FIGURES:
Table_A2_Concentration_Model_Data;                   % -> (Table*)  Concentration and competition, model versus data 
Figure_A1_Cross_Market_Concentration;                % -> (Figure*) Cross market distribution of concentration model v. data
Figure_A2_Identification;                            % -> (Figure*)  Identification of productivity dispersion sigma, and DRS ?
Figure_A3_Varying_Decreasing_Returns;                % -> (Figure*) Oligopsonistic equilibrium with varying decreasing returns ?
Figure_G1_Non_Wage_Benefits_and_Shares;              % -> (Figure*) Non-wage benefits and wage-bill shares
%__________________________________________________________________________
toc
close all;
