%% Figure 10: Measures of labor market concentration, 1977 to 2013
%% Figure 11: Change in labor share attributable to change in payroll Herfindahl, 1977 to 2013
clear;clc; close all;
load('Created_mat_files/Outputs_welfare','theta','eta','alpha','gamma')
year  = xlsread('Input_data_files/Clean_time_series_data.xlsx','Data','A6:A42');
X     = xlsread('Input_data_files/Clean_time_series_data.xlsx','Data','B6:Y42');
%__________________________________________________________________________
% HHI DATA
% 1. Compare industries
hhi_local_w_nontrade    = X(:,2);
hhi_local_w_trade       = X(:,10);
hhi_local_w_all         = X(:,18);

% 2. Compare local and national
hhi_national_w_nontrade = X(:,6); 
hhi_national_w_trade    = X(:,14); 
hhi_national_w_all      = X(:,22); 

% 3. Compare weighted unweighted
hhi_local_uw_trade      = X(:,9); 

% 4. Compare weighted unweighted
hhin_local_uw_trade     = X(:,11); 
hhin_local_w_trade      = X(:,12);  
%__________________________________________________________________________
% LABOR SHARE COMPUTATIONS
% Applying formula from text (equation 17)
LSt_trade       = gamma*alpha*( ((eta+1)/eta)*(1-hhi_local_w_trade)     + ((theta+1)/theta)*hhi_local_w_trade).^(-1);
LSt_nontrade    = gamma*alpha*( ((eta+1)/eta)*(1-hhi_local_w_nontrade)  + ((theta+1)/theta)*hhi_local_w_nontrade).^(-1);
LSt_all         = gamma*alpha*( ((eta+1)/eta)*(1-hhi_local_w_all)       + ((theta+1)/theta)*hhi_local_w_all).^(-1);

%__________________________________________________________________________
% Referenced in paper:
hhi_national_w_trade(end)/hhi_national_w_trade(1)
hhi_local_w_trade(end)/hhi_local_w_trade(1)
mean(hhi_local_uw_trade)/mean(hhi_local_w_trade)
corr(hhin_local_w_trade, hhi_local_w_trade)
%__________________________________________________________________________
% Smooth out plots
MA                      = 5;
hhi_local_w_nontrade    = fun_CMA(hhi_local_w_nontrade,MA); 
hhi_local_w_trade       = fun_CMA(hhi_local_w_trade,MA); 
hhi_local_w_all         = fun_CMA(hhi_local_w_all,MA); 
hhi_national_w_nontrade = fun_CMA(hhi_national_w_nontrade,MA); 
hhi_national_w_trade    = fun_CMA(hhi_national_w_trade,MA); 
hhi_national_w_all      = fun_CMA(hhi_national_w_all,MA); 
hhi_local_uw_trade      = fun_CMA(hhi_local_uw_trade,MA); 
hhin_local_uw_trade     = fun_CMA(hhin_local_uw_trade,MA); 
hhin_local_w_trade      = fun_CMA(hhin_local_w_trade,MA); 

LSt_trade               = fun_CMA(LSt_trade,MA); 
LSt_nontrade            = fun_CMA(LSt_nontrade,MA); 
LSt_all                 = fun_CMA(LSt_all,MA); 
%__________________________________________________________________________
% Plot parameters
yearlb                   = 1977;
yearub                   = 2013;
yearplot                 = (year>=yearlb) & (year<=yearub);

%% FIGURE 10
F1 = figure(2);
set(F1,'Pos',[84 401 2167 521]);
set(0,'defaultlinelinewidth',5);
set(0,'defaultlinemarkersize',9);
font = 20;

subplot(1,3,1); 
plot(year(yearplot),hhi_local_w_trade(yearplot),'k-');hold on; grid on;
plot(year(yearplot),hhi_local_w_nontrade(yearplot),'b-.');hold on; grid on;
plot(year(yearplot),hhi_local_w_all(yearplot),'r:');
xlabel('Year','interpreter','latex');
ylabel('$HHI$','interpreter','latex');
l = legend('Tradeable sectors','Non-tradeable sectors','All sectors');
set(l,'interpreter','latex','location','northeast');
title('A. Local (payroll weighted)','interpreter','latex');
set(gca,'ticklabelinterpreter','latex','fontsize',font);
ytickformat('%3.2f');
xlim([yearlb,yearub])

subplot(1,3,2); 
plot(year(yearplot),hhi_local_uw_trade(yearplot),'k:');hold on; grid on;
plot(year(yearplot),hhin_local_uw_trade(yearplot),'b:');hold on; grid on;
plot(year(yearplot),hhi_local_w_trade(yearplot),'k-');hold on; grid on;
plot(year(yearplot),hhin_local_w_trade(yearplot),'b-');hold on; grid on;
xlabel('Year','interpreter','latex');
ylabel('$HHI$','interpreter','latex');
l = legend('Payroll (unweighted)','Employment (unweighted)','Payroll (weighted)','Employment (weighted)');
set(l,'interpreter','latex','location','East','fontsize',font-4);
title('B. Comparing local measures','interpreter','latex');
set(gca,'ticklabelinterpreter','latex','fontsize',font);
ytickformat('%3.2f');ylim([0.10,0.55]);
xlim([yearlb,yearub])

subplot(1,3,3); 
plot(year(yearplot),hhi_national_w_trade(yearplot),'k-');hold on; grid on;
plot(year(yearplot),hhi_national_w_nontrade(yearplot),'b-.');hold on; grid on;
plot(year(yearplot),hhi_national_w_all(yearplot),'r:');
xlabel('Year','interpreter','latex');
ylabel('$HHI$','interpreter','latex');
l = legend('Tradeable sectors','Non-tradeable sectors','All sectors');
set(l,'interpreter','latex','location','northeast');
title('C. National (payroll weighted)','interpreter','latex');
set(gca,'ticklabelinterpreter','latex','fontsize',font);
ylim([0.004,0.020]);
ytickformat('%3.3f');
xlim([yearlb,yearub])

print('-depsc','Created_figure_files/Figure_10_Time_Series_Concentration_eps');

%% FIGURE 11
close all

F1 = figure(3);
set(F1,'Pos',[648 593 592 385]);
set(0,'defaultlinelinewidth',3);
set(0,'defaultlinemarkersize',9);
font = 16;
 
LSt_trade_plot       = LSt_trade(yearplot);
LSt_nontrade_plot    = LSt_nontrade(yearplot);
LSt_all_plot         = LSt_all(yearplot);

plot(year(yearplot),LSt_trade_plot-LSt_trade_plot(1),'k-');hold on; grid on;
plot(year(yearplot),LSt_nontrade_plot-LSt_nontrade_plot(1),'b-.');hold on; grid on;
plot(year(yearplot),LSt_all_plot-LSt_all_plot(1),'r:');hold on; grid on;
xlabel('Year','interpreter','latex');
ylabel('$LS_t-LS_{1977}$','interpreter','latex');
l = legend('Tradeable sectors','Non-tradeable sectors','All sectors');
set(l,'interpreter','latex','location','SouthEast');
title('Change in labor share due to $\Delta HHI^{wn}_t$','interpreter','latex');
set(gca,'ticklabelinterpreter','latex','fontsize',font);
ytickformat('%3.2f');
ylim([-0.02,0.05]);
xlim([yearlb,yearub])

print('-depsc','Created_figure_files/Figure_11_Time_Series_Labor_Share_eps');
 
