%% Figure 7 - Distribution of labor market power across firms
clear; close all;
load Created_mat_files/baseline_no_tax;
fprintf('Running: Figure_7_Distribution_of_Labor_Market_Power.m\n');

%% COMPUTATIONS
%__________________________________________________________________________
% Bin firms by their elasticities (Panel A)
egrid       = (0.5:1:11.5);    
fgrid_f     = zeros(numel(egrid)-1,1);  % Distribution of firms
fgrid_wn    = zeros(numel(egrid)-1,1);  % Distribution of wage payments
for ee = 1:numel(fgrid_f)
    fgrid_f(ee)  = sum(sum((eps_ij>=egrid(ee) & eps_ij<=egrid(ee+1))));         
    fgrid_wn(ee) = sum(sum(wn_ij(eps_ij>=egrid(ee) & eps_ij<=egrid(ee+1))));    
end
sum(fgrid_f)
fgrid_f     = fgrid_f/sum(fgrid_f);
fgrid_wn    = fgrid_wn/sum(fgrid_wn);
egrid       = 0.5*(egrid(1:end-1)+egrid(2:end));   % Get mid-points for x-axis
%__________________________________________________________________________
% Bin firms by their markdowns (Panel B)
mugrid      = [0.30:0.05:0.95]';
ggrid_f     = zeros(numel(mugrid)-1,1);  % Distribution of firms
ggrid_wn    = zeros(numel(mugrid)-1,1);  % Distribution of wage payments
for ee = 1:numel(ggrid_f)
    ggrid_f(ee)  = sum(sum((mu_ij>=mugrid(ee) & mu_ij<=mugrid(ee+1))));          
    ggrid_wn(ee) = sum(sum(wn_ij(mu_ij>=mugrid(ee) & mu_ij<=mugrid(ee+1))));     
end
sum(ggrid_f)
ggrid_f     = ggrid_f/sum(ggrid_f);
ggrid_wn    = ggrid_wn/sum(ggrid_wn);
mugrid       = 0.5*(mugrid(1:end-1)+mugrid(2:end));   % Get mid-points for x-axis

%% PLOT
font    = 20;
f2      = figure('name','figure2','position',[-186 381 1643 521]);
%__________________________________________________________________________
% For vertical lines in the plot load in aggregate 'mu' from the 
% welfare solution: Compute_welfare_results.m
X           = load('Created_mat_files/Outputs_welfare');
mustar      = X.mu_mat(2,1);
Estar       = mustar/(1-mustar);
% Wage weighted means of elasticity and markdown
epsbar_w    = sum(fgrid_wn.*egrid');
mubar_w     = sum(ggrid_wn.*mugrid);
% Unweighted means of elasticity and markdown
epsbar      = mean(eps_ij(n_ij>0));
mubar       = mean(mu_ij(n_ij>0));
%_________________________________________________________________________
% PANEL A
subplot(1,2,1);
a1 = bar(egrid,fgrid_f,1,'facecolor',rgb('red')); grid on;hold on;
a3 = bar(egrid,fgrid_wn,1,'facecolor',rgb('blue')); grid on;hold on;
a1.FaceAlpha = 0.5;
a3.FaceAlpha = 0.5;

plot([epsbar,epsbar],[0,1],'r:','linewidth',5);hold on;
plot([epsbar_w,epsbar_w],[0,1],'b-.','linewidth',5);hold on;
plot([Estar,Estar],[0,1],'-','color',rgb('Green'),'linewidth',5);hold on;
 set(gca,'XTick',[0,1,2,3,4,5,6,7,8,9,10,11]);
 set(gca,'XTickLabel',{'0','1','2','3','4','5','6','7','8','9','10','11'});
xlim([theta-0.01,11.5]);
title('A. Structural elasticities (model)','fontsize',font,'interpreter','latex');
xlabel('Elasticity - $\varepsilon_{ij}$','fontsize',font,'interpreter','latex');
ylabel('Fraction','fontsize',font,'interpreter','latex');
set(gca,'fontsize',font,'TickLabelInterpreter','latex');
set(gcf,'PaperPositionMode','auto');
l = legend('Firms','Wages',...
            'Mean - Unweighted','Mean - Wage weighted',...
            'Aggregate elasticity: $\mathcal{E}$');
set(l,'interpreter','latex','location','NorthWest','fontsize',font);
ylim([0,0.85]);
%_________________________________________________________________________
% PANEL B 
subplot(1,2,2);
a1 = bar(mugrid,ggrid_f,1,'facecolor',rgb('red')); grid on;hold on;
a3 = bar(mugrid,ggrid_wn,1,'facecolor',rgb('blue')); grid on;hold on;
a1.FaceAlpha = 0.5;
a3.FaceAlpha = 0.5;

fprintf('Unweighted average: Elast = %4.3f \t Mu = %4.3f\n',epsbar,mubar);
fprintf('Weighted average: Elast = %4.3f \t Mu = %4.3f\n',epsbar_w,mubar_w);
fprintf('Ideal: Elast = %4.3f \t Mu = %4.3f\n',Estar,mustar);

plot([mubar,mubar],[0,1],'r:','linewidth',5);hold on;
plot([mubar_w,mubar_w],[0,1],'b-.','linewidth',5);hold on;
plot([mustar,mustar],[0,1],'-','color',rgb('Green'),'linewidth',5);hold on;
title('B. Markdowns (model)','fontsize',font,'interpreter','latex');
ylabel('Fraction','fontsize',font,'interpreter','latex');
xlabel('Markdown - $\mu_{ij}$','fontsize',font,'interpreter','latex');
set(gca,'fontsize',font,'TickLabelInterpreter','latex');
set(gcf,'PaperPositionMode','auto');
l = legend('Firms','Wages',...
            'Mean - Unweighted','Mean - Wage weighted',...
            'Aggregate markdown: $\mu$');
set(l,'interpreter','latex','location','NorthWest','fontsize',font);
ylim([0,0.85]);
xlim([0.30,0.95]);
%__________________________________________________________________________
set(gcf,'PaperPositionMode','auto');
print('-depsc','Created_figure_files/Figure_7_Distribution_of_Labor_Market_Power_eps');
fprintf('done\n');


