%% Figure 8II: Employment reallocation from the benchmark economy to the efficient economy
clear;close all;
load('Created_mat_files/baseline_no_tax');
dbstop if error;
fprintf('Running: Figure_8II_Example_Oligopsony_Competitive.m\n');

%% COMPUTATIONS
%______________________________________________________________________
% Set up productivities of firms in the 3 markets
%______________________________________________________________________
Z0x     = z_ij(z_ij~=0);        % Take out all positive productivities
Qvec    = [10,50,90];           % Productivity percentiles of 3 firms
Zq      = prctile(Z0x,Qvec);

K       = numel(Zq);
M_max   = numel(Zq);
M       = zeros(K,1);
Z0      = zeros(M_max,K);
for kk = (1:K)
    M(kk)           = kk;
    for kkk = 1:kk
        Z0(kkk,kk)  = Zq(kkk);          
    end
end
%______________________________________________________________________
% Oligopsony
%______________________________________________________________________
    mu_ij           = zeros(M_max,K);      % Markdown
    what_ij         = zeros(M_max,K);      % Wage
    for jj=(1:K)  % J regions
        z_i                    = Z0(1:M(jj),jj); 
        eq0                    = fun_solve_market_Nash(z_i,param,val,glob,options);
        mu_ij(1:M(jj),jj)      = eq0.mu_i;
        what_ij(1:M(jj),jj)    = eq0.w_i;
    end
    w_ij    = omega^(1/(1+(1-alpha)*theta)) * W^( ((1-alpha)*(theta-varphi)) / (1+(1-alpha)*theta) ) .* what_ij;
    w_j     = sum(w_ij.^(eta+1)).^(1/(eta+1));
    n_ij    = varphibar*bsxfun(@times,bsxfun(@rdivide,w_ij,w_j).^eta,(w_j/W).^theta).*(W/1).^varphi;
    swn_ij  = bsxfun(@rdivide,w_ij.*n_ij,sum(w_ij.*n_ij));
%______________________________________________________________________    
% Competitive
%______________________________________________________________________
diff_max        = 1e-5 ;
it_max          = 1000 ;
diff            = 10   ;
it              = 0    ;
wc_high         = 10000000.*(Z0>0);     % Upper bound of competitive wages
wc_low          = 1.*(Z0>0);            % Lower bound of competitive wages
update_speed    = 0.5; 
Wc              = W; % PE comp eq.
while (diff>diff_max) && (it<it_max)
    it              = it+1 ;                                % Advance iteration
    wc_ij           = 0.5*wc_high + 0.5*wc_low;             % Update wage, bisection
    wc_j            = sum(wc_ij.^(eta+1)).^(1/(eta+1));     % Sectoral
    % Labor demand
    labor_demand    = (alpha*zbar*Z0./wc_ij).^(1/(1-alpha));
    % Labor supply
    labor_supply    = varphibar*bsxfun(@times,bsxfun(@rdivide,wc_ij,wc_j).^eta,(wc_j/Wc).^theta).*(Wc/1).^varphi;
    % Update bisection boundaries
    wc_high         =   (labor_supply>labor_demand) .*(update_speed*wc_ij+(1-update_speed)*wc_high) + ...  % Lower upper bound
                        (labor_supply<=labor_demand).*wc_high;
    wc_low          =   (labor_supply>labor_demand) .*wc_low + ...
                        (labor_supply<=labor_demand).*(update_speed*wc_ij+(1-update_speed)*wc_low);       % Raise lower bound
    % Distance
    diff            = max(max(abs(labor_supply-labor_demand)));
    if mod(it,10)==0
        display(['diff : ' num2str(diff) ' it : ' num2str(it)]);
    end
end
w_ijc   = wc_ij;
n_ijc   = labor_supply;
mu_ijc  = 0*w_ijc;
swn_ijc = bsxfun(@rdivide,w_ijc.*n_ijc,sum(w_ijc.*n_ijc));

%% FIGURE
F9      = figure(round(1000*rand));
set(F9,'Pos',[333 157 1779 963]);
set(0,'defaultlinelinewidth',3);
set(0,'defaultlinemarkersize',15);
font    = 28;
clf;
%__________________________________________________________________________
% A. SHARES
subplot(2,2,1);
X           = swn_ij;
X(X==0)     = NaN;
plot(Qvec,X(:,3),'s-','color',rgb('Blue'));hold on;
X           = swn_ijc;
X(X==0)     = NaN; 
plot(Qvec,X(:,3),'o-.','color',rgb('Red'));hold on;    
grid on;
ylim([0,1]);
xlim([min(Qvec),max(Qvec)]);
set(gca,'XTick',Qvec);
title('II(a) Market share: $s_{ij}$','interpreter','latex','fontsize',font);
set(gca,'YTick',[0,0.25,0.50,0.75,1.0],'YTickLabel',{'0','0.25','0.50','0.75','1.00'});
set(gca,'XTick',[10,50,90],'XTickLabel',{'$z_{Low}$','$z_{Med}$','$z_{High}$'});xlim([5,95]);
l = legend('Oligopsony economy','Efficient economy');
set(l,'location','NorthWest','interpreter','latex','fontsize',font-4);
hold on;
set(gca,'fontsize',font-4,'ticklabelinterpreter','latex');
%__________________________________________________________________________
% B. MARKDOWNS
subplot(2,2,2);
X           = mu_ij;
X(X==0)     = NaN; 
plot(Qvec,X(:,3),'s-','color',rgb('Blue'));hold on;
ylim([0.3,0.89]);
X(~isnan(X))   = 1;
plot(Qvec,X(:,3),'o-.','color',rgb('Red'));hold on;   
set(gca,'YTick',[theta/(theta+1),0.40,0.50,0.60,0.70,0.80,eta/(eta+1),1]);
set(gca,'YTickLabel',{'$\frac{\theta}{\theta+1}$','0.40','0.50','0.60','0.70','0.80','$\frac{\eta}{\eta+1}$','1'});
ylim([0.3,1]);
title('II(b) Markdown: $\mu_{ij}$','interpreter','latex','fontsize',font);
grid on;
xlim([min(Qvec),max(Qvec)]);
set(gca,'XTick',Qvec);
plot([0,100],[eta/(eta+1),eta/(eta+1)],'k--');hold on;
plot([0,100],[theta/(theta+1),theta/(theta+1)],'k:');hold on;
set(gca,'fontsize',font-4,'ticklabelinterpreter','latex');
set(gca,'XTick',[10,50,90],'XTickLabel',{'$z_{Low}$','$z_{Med}$','$z_{High}$'});xlim([5,95]);
%__________________________________________________________________________
% C. WAGES
subplot(2,2,3);
X           = w_ij/1000;
X(X==0)     = NaN;
plot(Qvec,X(:,3),'s-','color',rgb('Blue'));hold on;
X           = w_ijc/1000;
X(X==0)     = NaN; 
plot(Qvec,X(:,3),'o-.','color',rgb('Red'));hold on;    
grid on;
ylim([10,60]);
xlim([min(Qvec),max(Qvec)]);
set(gca,'XTick',Qvec);
set(gca,'XTick',[10,50,90],'XTickLabel',{'$z_{Low}$','$z_{Med}$','$z_{High}$'});xlim([5,95]);
title('II(c) Wage (\$000s): $w_{ij} = \mu_{ij}mrpl_{ij}$','interpreter','latex','fontsize',font);
set(gca,'fontsize',font-4,'ticklabelinterpreter','latex');
%__________________________________________________________________________
% D. EMPLOYMENT
subplot(2,2,4);
X           = n_ij;
X(X==0)     = NaN;
plot(Qvec,X(:,3),'s-','color',rgb('Blue'));hold on;
set(gca,'YTick',[0:100:500]);
X           = n_ijc;
X(X==0)     = NaN; 
plot(Qvec,X(:,3),'o-.','color',rgb('Red'));hold on;    
set(gca,'YTick',[0:200:1100]);
ylim([0,1100]);
xlim([min(Qvec),max(Qvec)]);
set(gca,'XTick',Qvec);
set(gca,'XTick',[10,50,90],'XTickLabel',{'$z_{Low}$','$z_{Med}$','$z_{High}$'});xlim([5,95]);
title('II(d) Employment: $n_{ij}$','interpreter','latex','fontsize',font);
set(gca,'fontsize',font-4,'ticklabelinterpreter','latex');
grid on;

%% SAVE
set(gcf,'PaperPositionMode','auto');
print '-depsc' Created_figure_files/Figure_8II_Example_Oligopsony_Competitive_eps
