%% Figure 9 - Welfare costs of labor market power with wealth effects
clear;clc;close all;
fprintf('Running: Figure_9_Welfare_Costs_with_Wealth_Effects\n');
%__________________________________________________________________________
% LOAD IN THE MINIMAL SET OF OBJECTS TO SOLVE THE MODEL:
load('Created_mat_files/baseline_no_tax','param','glob','mu_ij','z_ij','Mj');

varphi_vec          = [0.10,0.20,0.30,0.40,0.50,0.75,1.00,1.25,1.50,2.00];
sigma_vec           = [0,1.001,1.20:0.20:4];

Nvarphi             = numel(varphi_vec);
Nsigma              = numel(sigma_vec);
%__________________________________________________________________________
% STORAGE FOR RESULTS
varphi_mat          = zeros(Nvarphi,Nsigma);
sigma_mat           = zeros(Nvarphi,Nsigma);
lambdaE_mat         = zeros(Nvarphi,Nsigma);
lambdaE_omega_mat   = zeros(Nvarphi,Nsigma);
Y_mat               = zeros(Nvarphi,Nsigma);
Yc_mat              = zeros(Nvarphi,Nsigma);
%__________________________________________________________________________
% BASELINE
param.varphi                = 0.50;
param.sigma                 = 0;
options.solve_scale         = 'Y';  % Recalibrate scaling parameters (varphibar,Zbar)
out                         = fun_welfare_closed_form(mu_ij,z_ij,Mj,[],[],param,glob,options);
glob.zbar                   = out.Ztilde;
glob.varphibar              = out.varphibar;
mu_base                     = out.mu;
omega_base                  = out.omega;
save('Created_mat_files/base_mu_omega','mu_base','omega_base');
%__________________________________________________________________________
% SOLVE MODEL UNDER OLIGOPSONY AND COMPETITIVE FOR ALTERNATIVE VALUES OF (varphi,sigma)
for vv = (1:Nvarphi)
    for ss = (1:Nsigma)
        display(['vv/Nvarphi = ' num2str(vv/Nvarphi) ', ss/Nsigma = ' num2str(ss/Nsigma)]);
        %__________________________________________________________________
        % Unpack parameters
        param.varphi                = varphi_vec(vv);
        param.sigma                 = sigma_vec(ss);
        %__________________________________________________________________
        % Options
        options.solve_scale         = 'Y';  % Recalibrate (varphibar and Zbar) to match same moments 
        muc                         = 1;    % Competitive aggregate markdown
        omegac                      = 1;    % Competitive aggregate misallocation
        %__________________________________________________________________
        % Recalibrate and solve oligopsony and competitive economies
        out                         = fun_welfare_closed_form(mu_ij,z_ij,Mj,muc,omegac,param,glob,options);
        %__________________________________________________________________
        % Store outputs for figure
        varphi_mat(vv,ss)           = param.varphi;
        sigma_mat(vv,ss)            = param.sigma;
        lambdaE_mat(vv,ss)          = out.lambdaE;
        lambdaE_omega_mat(vv,ss)    = out.lambdaE_omega;
        Y_mat(vv,ss)                = out.Y;
        Yc_mat(vv,ss)               = out.Yc;
        %__________________________________________________________________
    end
end

%% FIGURE
F1 = figure(1);
set(F1,'Pos',[573 459.6667 932 398.6667]);
set(0,'defaultlinelinewidth',2);
font = 14;

lambda_base         = lambdaE_mat(varphi_vec==0.5,sigma_vec==0);
frac_omega_base     = lambdaE_omega_mat(varphi_vec==0.5,sigma_vec==0)/lambda_base;

dY_mat              = Yc_mat./Y_mat-1;
dY_base             = dY_mat(varphi_vec==0.5,sigma_vec==0);

splot               = 1.02;     % Dummy sigma for plotting GHH baseline

subplot(1,2,1);
plot3(varphi_mat(:,1),splot+0*sigma_mat(:,1),100*dY_mat(:,1),'r:');grid on;hold on;
plot3(varphi_mat(:,2:end),sigma_mat(:,2:end),100*dY_mat(:,2:end),'b-');grid on;hold on;
plot3(0.5,splot+0*0,100*dY_base,'ro','markersize',15);
view(-46,17);
xlabel('Frisch: $\varphi$','interpreter','latex');
xtickformat('%3.0f');
ylabel('CRRA: $\sigma$','interpreter','latex');
text(0.1,3.8,17.0,'\textbf{O} = GHH Baseline','color',rgb('Red'),'interpreter','latex','fontsize',font);
title('A. Output increase, percent','interpreter','latex');
zlim([5,25]);
set(gca,'fontsize',font,'ticklabelinterpreter','latex');

subplot(1,2,2);
plot3(varphi_mat(:,1),splot+0*sigma_mat(:,1),lambdaE_omega_mat(:,1)./lambdaE_mat(:,1),'r:');grid on;hold on;
plot3(varphi_mat(:,2:end),sigma_mat(:,2:end),lambdaE_omega_mat(:,2:end)./lambdaE_mat(:,2:end),'b-');grid on;hold on;
plot3(0.5,splot+0*0,frac_omega_base,'ro','markersize',15);
view(-46,17);
xlabel('Frisch: $\varphi$','interpreter','latex');
xtickformat('%3.0f');
ylabel('CRRA: $\sigma$','interpreter','latex');
title('B. Share of welfare gain due to misallocation','interpreter','latex');
zlim([0.15,0.92]);
zticks([0.1:0.1:0.9]);
set(gca,'fontsize',font,'ticklabelinterpreter','latex');

print '-depsc'  'Created_figure_files/Figure_9_Welfare_Costs_with_Wealth_Effects_eps'

