%% Figure A1: Cross market distribution of concentration model v. data
clear; clc;close all;
load('Created_mat_files/baseline_tax');
fprintf('Figure_A1_Cross_Market_Concentration\n');

%% LOAD IN DATA FROM CENSUS OUTPUT:
% 2014
% Source data: 
% ..\12_released_census_data\summary_stats_agg_v1_tradeable_wins
hist_hhi_wtd_data	=[0.04931
0.3184
0.1877
0.2116
0.143
0.05499
0.02876
0.006213]; %Tradeable only
			
hist_hhi_uwtd_data	=[	0.003055
0.05601
0.0702
0.1982
0.2482
0.1558
0.09973
0.1688];
    
hist_hhi_wtd_data_all	=[	0.212
0.3405
0.1448
0.176
0.08957
0.02412
0.01131
0.001778]; %All (both tradeable and non-tradeable)

hist_hhi_uwtd_data_all	=[	0.01381
0.1249
0.1339
0.2539
0.2082
0.1127
0.05606
0.09657];

% Aggregate data so consistent with model bins
cut                     = 4;
hist_hhi_wtd_data       = [sum(hist_hhi_wtd_data(1:cut));hist_hhi_wtd_data(cut+1:8)];
hist_hhi_wtd_data_all   = [sum(hist_hhi_wtd_data_all(1:cut));hist_hhi_wtd_data_all(cut+1:8)];
hist_hhi_uwtd_data      = [sum(hist_hhi_uwtd_data(1:cut));hist_hhi_uwtd_data(cut+1:8)];
hist_hhi_uwtd_data_all  = [sum(hist_hhi_uwtd_data_all(1:cut));hist_hhi_uwtd_data_all(cut+1:8)];

%% COMPUTATIONS

% Market level
n_j     = sum(n_ij);
wn_j    = sum(w_ij.*n_ij);
w_j     = wn_j./n_j;

% HHI
sn_ij   = bsxfun(@rdivide,n_ij,sum(n_ij));
swn_ij  = bsxfun(@rdivide,w_ij.*n_ij,sum(w_ij.*n_ij));
HHIn_j  = sum(sn_ij.^2)';
HHIwn_j = sum(swn_ij.^2)';

% Shares
swn_j   = wn_j./sum(wn_j);                          % Share of wage payments
sf_j    = Mj./sum(Mj);                              % Share of firms
sm_j    = ones(size(Mj))./sum(ones(size(Mj)));      % Share of markets

% Bounds on bins for histogram
hhi_l   = [0.00,0.25,0.50,0.75,0.99]';
hhi_u   = [0.25,0.50,0.75,0.99,1.00]';

% Compute histograms
bin_mid                 = (hhi_l + hhi_u)/2;
Nbin                    = numel(hhi_l);

hist_hhi_wtd            = zeros(Nbin,1);
hist_hhi_uwtd           = zeros(Nbin,1);
for bb = (1:Nbin)
    i                        = (HHIwn_j>hhi_l(bb) & HHIwn_j<=hhi_u(bb));
    hist_hhi_wtd(bb)        = sum(swn_j(i));
    hist_hhi_uwtd(bb)       = sum(sm_j(i));
end
 
%% FIGURE
F1 = figure(1);
set(F1,'Pos',[248 463 1371 496]);
font = 22;
set(0,'defaultlinelinewidth',5);
set(0,'defaultlinemarkersize',15);

bin_Mj  = [1:1:200]';
hist_Mj = zeros(size(bin_Mj));
for jj=(1:numel(hist_Mj))
    hist_Mj(jj) = sum(Mj==bin_Mj(jj));
end
hist_Mj = hist_Mj/sum(hist_Mj);
 
subplot(1,2,1);
plot(bin_mid,hist_hhi_wtd,'b-');           hold on;
plot(bin_mid,hist_hhi_wtd_data,'r--');     hold on;
plot(bin_mid,hist_hhi_wtd_data_all,'r:');  hold on;
grid on;
l = legend('Model','Data - Tradeable sectors','Data - All sectors');
set(l,'interpreter','latex');
xlabel('Market Herfindahl index - $hhi^{wn}_j$','fontsize',font,'interpreter','latex');
ylabel('Fraction of payroll','fontsize',font,'interpreter','latex');
title('(i) Distribution of wage payments','fontsize',font,'interpreter','latex');
set(gca,'fontsize',font,'ticklabelinterpreter','latex');
ytickformat('%3.2f');
ylim([0,1]);

subplot(1,2,2);
plot(bin_mid,hist_hhi_uwtd,'b-');hold on;
plot(bin_mid,hist_hhi_uwtd_data,'r--');hold on;
plot(bin_mid,hist_hhi_uwtd_data_all,'r:');hold on;
grid on;
l = legend('Model','Data - Tradeable sectors','Data - All sectors');
set(l,'interpreter','latex');
xlabel('Market Herfindahl index - $hhi^{wn}_j$','fontsize',font,'interpreter','latex');
ylabel('Fraction of markets','fontsize',font,'interpreter','latex');
title('(ii) Distribution of markets','fontsize',font,'interpreter','latex');
set(gca,'fontsize',font,'ticklabelinterpreter','latex');
ytickformat('%3.2f');
ylim([0,1]);

print('-depsc','Created_figure_files/Figure_A1_Cross_Market_Concentration_eps'); 

return